==> monodevelop-2.2.2.tar.bz2: monodevelop-2.2.2/src/addins/MonoDevelop.AssemblyBrowser/MonoDevelop.AssemblyBrowser/DisplayBinding.cs <==
//
// DisplayBinding.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.IO;
using MonoDevelop.Core.Gui;
using MonoDevelop.Ide.Codons;
using MonoDevelop.Ide.Gui;
using MonoDevelop.Core;

namespace MonoDevelop.AssemblyBrowser
{
	public class DisplayBinding : DefaultDisplayBinding
	{
		public override string Name {
			get {
				return GettextCatalog.GetString ("Assembly Browser");
			}
		}
		
		AssemblyBrowserViewContent viewContent = null;
		
		AssemblyBrowserViewContent GetViewContent ()
		{
			if (viewContent == null || viewContent.IsDisposed) {
				viewContent = new AssemblyBrowserViewContent ();
				viewContent.Control.Destroyed += delegate {
					this.viewContent = null;
				};
			}
			return viewContent;
		}
		
		public override bool CanCreateContentForMimeType (string mimeType)
		{
			return mimeType == "application/x-ms-dos-executable" || mimeType == "application/x-executable";
		}
		
		public override IViewContent CreateContentForMimeType (string mimeType, System.IO.Stream content)
		{
			return GetViewContent ();
		}
	}
}

==> monodevelop-2.4.tar.bz2: monodevelop-2.4/src/addins/MonoDevelop.AssemblyBrowser/MonoDevelop.AssemblyBrowser/DisplayBinding.cs <==
//
// DisplayBinding.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.IO;
using MonoDevelop.Ide.Codons;
using MonoDevelop.Ide.Gui;
using MonoDevelop.Core;

namespace MonoDevelop.AssemblyBrowser
{
	public class AssemblyBrowserDisplayBinding : DisplayBinding
	{
		public override string Name {
			get {
				return GettextCatalog.GetString ("Assembly Browser");
			}
		}
		
		AssemblyBrowserViewContent viewContent = null;
		
		AssemblyBrowserViewContent GetViewContent ()
		{
			if (viewContent == null || viewContent.IsDisposed) {
				viewContent = new AssemblyBrowserViewContent ();
				viewContent.Control.Destroyed += delegate {
					this.viewContent = null;
				};
			}
			return viewContent;
		}
		
		public override bool CanCreateContentForMimeType (string mimeType)
		{
			return mimeType == "application/x-ms-dos-executable" || mimeType == "application/x-executable" || mimeType == "application/x-msdownload";
		}
		
		public override IViewContent CreateContentForMimeType (string mimeType, System.IO.Stream content)
		{
			return GetViewContent ();
		}
	}
}
